summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontact.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/libkopete/kopetecontact.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopetecontact.h')
-rw-r--r--kopete/libkopete/kopetecontact.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopetecontact.h b/kopete/libkopete/kopetecontact.h
index 4f8454fc..e24e23f0 100644
--- a/kopete/libkopete/kopetecontact.h
+++ b/kopete/libkopete/kopetecontact.h
@@ -73,7 +73,7 @@ public:
/**
* \brief Create new contact.
*
* <b>The tqparent MetaContact must not be NULL</b>
*
* \note id is required to be unique per protocol and per account.
* Across those boundaries ids may occur multiple times.
@@ -82,12 +82,12 @@ public:
* value! Even if it may look like an ICQ UIN or an MSN passport,
* this is undefined and may change at any time!
*
* @param account is the tqparent account. this constructor automatically register the contact to the account
* @param id is the Contact's unique Id (mostly the user's login)
* @param tqparent is the tqparent @ref MetaContact this Contact is part of
* @param icon is an optional icon
*/
- Contact( Account *account, const TQString &id, MetaContact *tqparent,
+ Contact( Account *account, const TQString &id, MetaContact *parent,
const TQString &icon = TQString() );
~Contact();
@@ -218,7 +218,7 @@ public:
* which is displayed in showContextMenu (private). Protocols
* should use this to add protocol-specific actions to the
* popup menu. Kopete take care of the deletion of the action collection.
* Actions should have the collection as tqparent.
*
* @return Collection of menu items to be show on the context menu
* @todo if possible, try to use KXMLGUI
@@ -449,7 +449,7 @@ public slots:
*
* default implementation does nothing
*
- * @param changed is a bittqmask of the @ref Changed enum which say why the call to this funtion is done.
+ * @param changed is a bitmask of the @ref Changed enum which say why the call to this funtion is done.
*/
virtual void sync(unsigned int changed = 0xFF);
@@ -73,7 +73,7 @@ public:
* \brief Create new contact.
*
- * <b>The tqparent MetaContact must not be NULL</b>
+ * <b>The parent MetaContact must not be NULL</b>
*
* \note id is required to be unique per protocol and per account.
@@ -82,12 +82,12 @@ public:
* this is undefined and may change at any time!
*
- * @param account is the tqparent account. this constructor automatically register the contact to the account
+ * @param account is the parent account. this constructor automatically register the contact to the account
* @param id is the Contact's unique Id (mostly the user's login)
@@ -82,12 +82,12 @@ public:
* @param id is the Contact's unique Id (mostly the user's login)
- * @param tqparent is the tqparent @ref MetaContact this Contact is part of
+ * @param parent is the parent @ref MetaContact this Contact is part of
* @param icon is an optional icon
*/
@@ -218,7 +218,7 @@ public:
* should use this to add protocol-specific actions to the
* popup menu. Kopete take care of the deletion of the action collection.
- * Actions should have the collection as tqparent.
+ * Actions should have the collection as parent.
*
* @return Collection of menu items to be show on the context menu